##  Use Reports and Diagrams to Visualize the Transformation Scope
One of the first outcomes of the data gathering and scoping will be a validated Business Capability Map and a view of capabilities in scope.
  * Create a Landscape Report with Business Capabilities mapped to Objectives that shows how your in-scope capabilities will improve to support your strategic Objectives driving the transformation. This view reflects the business architecture target state - the aspiration of where your organization is heading with this transformation on a business level. The color coding of the Business Capabilities reflects the three Pace Layers Commodity, Differentiation, Innovation (as per selected Report View “Strategic Importance”):
![Landscape Report with Business Capabilities mapped to Objectives](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275264087a441014a47a8481820c399d_LowRes.png)
Landscape Report with Business Capabilities mapped to Objectives
  * Create an Application Landscape Report that shows which active Applications are affected by the transformation (achieved through a clustering by Business Capabilities in scope) and what their current status of Functional Fit (stars on the left-hand side) and Technical Fit (stars on the right-hand side) are. To learn more about Landscape Report, check [Landscape Report](https://help.sap.com/docs/leanix/ea/landscape-report?locale=en-US&state=PRODUCTION&version=CLOUD).
![Active Applications with Functional and Technical Fit](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274894757a441014acd0e9d600f08058_LowRes.png)
Active Applications with Functional and Technical Fit
  * Create a Matrix Report showing which Applications are affected in which parts of your Organizations (e.g., Regions and/or Business Units) by the ERP transformation (clustered by the Business Applications in the scope of the transformation). To learn more on Matrix report, see [Matrix Report](https://help.sap.com/docs/leanix/ea/matrix-report?locale=en-US&state=PRODUCTION&version=CLOUD).
![Matrix Reports showing Applications affected in different Organizations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753ebaa7a441014b642efaef46a9dc0_LowRes.png)
Matrix Reports showing Applications affected in different Organizations


In the next step, you want to understand all your interfaces, e.g., by sending a [survey](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.") to all Application Owners to review all their Applications and verify existing or missing interfaces (and technical details related to those). You can use a [quality seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.") to ensure that you have all the information needed (e.g., technical dependency).
**Note**
If you are doing an SAP transformation, you can leverage Bill of Materials
  * Create an Interface Circle Map showing dependencies between different ERP solutions, and understand your integration architecture. You can read more about Interface Circle Map [here](https://help.sap.com/docs/leanix/ea/circle-map-report?locale=en-US&state=PRODUCTION&version=CLOUD). You can use it as a starting point to explore data flows.
![Interface Circle Map](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755c66e7a44101496c6a83ba0fb0703_LowRes.png)
Interface Circle Map
  * Leverage the Data Flow Diagram for a closer look at Interfaces: At this step, typically, an Integration Architect would dig deeper and work with Application Owners and Solution Architects to verify/capture technical dependencies. This will inform your overall planning of the program. For information on the Data Flow Diagram, check [Data Flow Diagram](https://help.sap.com/docs/leanix/ea/data-flow?locale=en-US&state=PRODUCTION&version=CLOUD).
![Data Flow Diagram To Have a Closer Look at Interfaces](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27575ded7a441014a148d1647492e71c_LowRes.png)
Data Flow Diagram To Have a Closer Look at Interfaces
